# node http exception library

## Features

- Handle common HTTP error with dedicated exception classes.
- Generate error responses with customizable error messages and status codes.
- Fully typescript support.

To install, you can use [npm](https://npmjs.org/) or [yarn](https://yarnpkg.com):

    $ npm install --save node-http-exceptions
    $ yarn add node-http-exceptions

## Examples

Here is simple example:

```js
import { Router } from 'express'
const { UnauthorizedException, BadRequestException, UnprocessableEntityException } = require( 'node-http-exceptions')

const routes = Router()

routes.post('/tasks', function (req, res, next) {
  try{
    if (!req.user){
        throw new UnauthorizedException('You are unauthorized.')
    }

    if ( !req.body ) ) {
        throw new BadRequestException( 'Task data is empty' )
    }

    if ( !req.body.name ) ) {
        throw new UnprocessableEntityException( 'Please fills all required fields.', {
          errors: { name: 'Name should not be empty.' }
        } )
    }

    //create task

  }catch(err){throw new UnprocessableEntityException( 'Please fills all required fields.', {
          errors: { name: 'Name should not be empty.' }
        } )
    next(err)
  }
})
```

Handle error using middleware:

```js
const { errorMiddleware, notFoundMiddleware } = require( 'node-http-exceptions')
const express = require('express')
const routes = require('./src/routes')

const app = express()

app.use(routes)

//handle errors
app.use(notFoundMiddleware)
app.use(errorMiddleware)
```

Use base HttpException

```js
const { HttpException, httpStatus } = require( 'node-http-exceptions')
const express = require('express')

const app = express()

app.post('/tasks', function (req, res, next) {
  try{
    if (!req.user){
        throw new HttpException(httpStatus.UNAUTHORIZED, 'You are unauthorized.')
    }

    //do something

  }catch(err){
    next(err)
  }
})
```

## The httpStatus object

Note that the `node-http-exceptions` also imports a httpStatus object:

```js
import { httpStatus } from 'node-http-exceptions'

console.log(httpStatus.OK) // Output: 200
console.log(httpStatus.NOT_FOUND) // Output: 404
```

## Which exception classes this package provides?

`node-http-exceptions` provides a set of exception classes that inherit from the base HttpException.
These classes represent many of the most common HTTP exceptions:

- **BadRequestException**
- **UnauthorizedException**
- **NotFoundException**
- **ForbiddenException**
- **NotAcceptableException**
- **RequestTimeoutException**
- **ConflictException**
- **PayloadTooLargeException**
- **UnsupportedMediaTypeException**
- **UnprocessableEntityException**
- **InternalServerErrorException**
- **ServiceUnavailableException**
